Djamo
=====

Yet another Mongodb driver for Django web framework.

FAQ
===

Why do you build an other one?
------------------------------
1. I'm not satisfied with exists drivers.
2. I don't need a complex driver, a simple and handy one is better for me.

Why did you start Djamo version from 2.67?
------------------------------------------
Because I'm a big fan of 'Steins Gate' anime. The main character "Okarin" use 2.67 version always as the begining version of his works.